Learn R Programming

MKpower (version 0.9)

print.power.mpe.test: Print Methods for Hypothesis Tests, Sample size and Power Calculations

Description

Printing objects of class "power.mpe.test" by simple print methods.

Usage

# S3 method for power.mpe.test
print(x, digits = getOption("digits"), ...)

Value

the argument x, invisibly, as for all print

methods.

Arguments

x

object of class "power.mpe.test".

digits

number of significant digits to be used.

...

further arguments to be passed to or from methods.

Author

Srinath Kolampally, Matthias Kohl Matthias.Kohl@stamats.de

Details

The print method is based on the respective method print.power.htest of package stats.

A power.mpe.test object is just a named list of numbers and character strings, supplemented with method and note elements. The method is displayed as a title, the note as a footnote, and the remaining elements are given in an aligned ‘name = value’ format.

See Also

print.power.htest, power.mpe.known.var, power.mpe.unknown.var

Examples

Run this code
(pkv <- power.mpe.known.var(K = 2, delta = c(1,1), Sigma = diag(c(2,2)), power = 0.9,
                            sig.level = 0.025))
print(pkv, digits =  4) # using less digits than default
print(pkv, digits = 12) # using more digits than default

Run the code above in your browser using DataLab